@@ -9,7 +9,8 @@
 #ifndef GLOBALCONTACTMODEL_H
 #define GLOBALCONTACTMODEL_H
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ChangeRecorder;
 class ContactsTreeModel;
 class Monitor;
