@@ -2,7 +2,7 @@
   This file is part of KAddressBook.
   SPDX-FileCopyrightText: 2002 Anders Lund <anders.lund@lund.tdcadsl.dk>
   SPDX-FileCopyrightText: Tobias Koenig <tokoe@kde.org>
-  SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
@@ -10,8 +10,8 @@
 #ifndef STYLEPAGE_H
 #define STYLEPAGE_H
 
-#include <QWidget>
 #include "importexport/contactfields.h"
+#include <QWidget>
 
 class QLabel;
 class QPixmap;
@@ -23,7 +23,7 @@ class StylePage : public QWidget
 
 public:
     explicit StylePage(QWidget *parent = nullptr, const QString &name = QString());
-    ~StylePage();
+    ~StylePage() override;
 
     /**
      * Set a preview image. If @p pixmap is 'null' a text will
