@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef KADDRESSBOOKUSERFEEDBACKPROVIDER_H
 #define KADDRESSBOOKUSERFEEDBACKPROVIDER_H
 
-#include <KUserFeedback/Provider>
 #include "kaddressbook_export.h"
+#include <KUserFeedback/Provider>
 
 class KADDRESSBOOK_EXPORT KAddressBookUserFeedbackProvider : public KUserFeedback::Provider
 {
     Q_OBJECT
 public:
     explicit KAddressBookUserFeedbackProvider(QObject *parent = nullptr);
-    ~KAddressBookUserFeedbackProvider();
+    ~KAddressBookUserFeedbackProvider() override;
 };
 
 #endif // KADDRESSBOOKUSERFEEDBACKPROVIDER_H
